Met.Show <-
function()
{
  showData2(datos$datos,title="Data")
  showData2(datos$info,title="Info")
}

